@@ -74,8 +74,6 @@ ArkViewer::ArkViewer(QWidget * parent)
     m_widget = new KVBox(this);
     m_widget->layout()->setSpacing(10);
 
-    connect(this, SIGNAL(finished()), this, SLOT(slotFinished()));
-
     setMainWidget(m_widget);
 }
 
@@ -83,13 +81,6 @@ ArkViewer::~ArkViewer()
 {
 }
 
-void ArkViewer::slotFinished()
-{
-    delete m_part;
-    m_part = 0;
-    delayedDestruct();
-}
-
 void ArkViewer::view(const QString& filename, QWidget *parent)
 {
     KService::Ptr viewer = ArkViewer::getViewer(filename);
