@@ -26,7 +26,7 @@
 #include "arkviewer.h"
 #include "kerfuffle/extractiondialog.h"
 #include "kerfuffle/jobs.h"
-#include "settings.h"
+#include "kerfuffle/settings.h"
 #include "jobtracker.h"
 #include "dnddbusinterface.h"
 
@@ -261,8 +261,8 @@ void Part::updateActions()
     const QStringList dirHistory = conf.readPathEntry("History Items", QStringList());
 
     for (int i = 0; i < qMin(10, dirHistory.size()); ++i) {
-        QAction *newAction = m->addAction(KUrl(dirHistory.at(i)).path());
-        newAction->setData(KUrl(dirHistory.at(i)).path());
+        QAction *newAction = m->addAction(KUrl(dirHistory.at(i)).pathOrUrl());
+        newAction->setData(KUrl(dirHistory.at(i)).pathOrUrl());
     }
 }
 
@@ -515,38 +515,11 @@ void Part::slotExtractFiles()
 
     dialog->setCurrentUrl(QFileInfo(m_model->archive()->fileName()).path());
 
-    dialog->setOpenDestinationFolderAfterExtraction(ArkSettings::openDestinationFolderAfterExtraction());
-
-    //TODO: remember this in arksettings
-    dialog->setPreservePaths(true);
-
     if (dialog->exec()) {
-        ArkSettings::setOpenDestinationFolderAfterExtraction(dialog->openDestinationAfterExtraction());
-
-        ArkSettings::self()->writeConfig();
-
         //this is done to update the quick extract menu
         updateActions();
 
-        QString destinationDirectory;
-        if (dialog->extractToSubfolder()) {
-            destinationDirectory =  dialog->destinationDirectory().path() +
-                                    QDir::separator() + dialog->subfolder();
-
-            if (!KStandardDirs::makeDir(destinationDirectory)) {
-                KMessageBox::error(NULL, i18n("The folder '%1' could not be created. Please check permissions.", destinationDirectory));
-                return;
-            }
-
-            lastExtractionFolder = destinationDirectory;
-        } else {
-            destinationDirectory = dialog->destinationDirectory().path();
-
-            if (isSingleFolderArchive())
-                lastExtractionFolder = destinationDirectory + QDir::separator() + detectSubfolder();
-            else
-                lastExtractionFolder = destinationDirectory;
-        }
+        m_destinationDirectory = dialog->destinationDirectory().pathOrUrl();
 
         QList<QVariant> files;
 
@@ -563,7 +536,7 @@ void Part::slotExtractFiles()
         if (dialog->preservePaths())
             options["PreservePaths"] = true;
 
-        ExtractJob *job = m_model->extractFiles(files, destinationDirectory, options);
+        ExtractJob *job = m_model->extractFiles(files, m_destinationDirectory, options);
         registerJob(job);
 
         connect(job, SIGNAL(result(KJob*)),
@@ -571,6 +544,8 @@ void Part::slotExtractFiles()
 
         job->start();
     }
+
+    delete dialog;
 }
 
 QList<QVariant> Part::selectedFilesWithChildren()
@@ -619,12 +594,12 @@ QList<QVariant> Part::selectedFiles()
 
 void Part::slotExtractionDone(KJob* job)
 {
-    kDebug(1601) ;
+    kDebug(1601);
     if (job->error()) {
         KMessageBox::error(widget(), job->errorString());
     } else {
         if (ArkSettings::openDestinationFolderAfterExtraction()) {
-            KUrl destinationFolder(lastExtractionFolder);
+            KUrl destinationFolder(m_destinationDirectory);
             destinationFolder.cleanPath();
 
             KRun::runUrl(destinationFolder, "inode/directory", widget());
