@@ -52,8 +52,8 @@ ParameterList CliPlugin::parameterList() const
         p[ListProgram] = p[ExtractProgram] = "unrar";
         p[DeleteProgram] = p[AddProgram] = "rar";
 
-        p[ListArgs] = QStringList() << "v" << "-c-" << "$Archive";
-        p[ExtractArgs] = QStringList() << "-p-" << "$PreservePathSwitch" << "$PasswordSwitch" << "$RootNodeSwitch" << "$Archive" << "$Files";
+        p[ListArgs] = QStringList() << "v" << "-c-" << "-v" << "$Archive";
+        p[ExtractArgs] = QStringList() << "-kb" << "-p-" << "$PreservePathSwitch" << "$PasswordSwitch" << "$RootNodeSwitch" << "$Archive" << "$Files";
         p[PreservePathSwitch] = QStringList() << "x" << "e";
         p[RootNodeSwitch] = QStringList() << "-ap$Path";
         p[PasswordSwitch] = QStringList() << "-p$Password";
