@@ -19,27 +19,29 @@
 
 #ifndef KWALLETMANAGER_H
 #define KWALLETMANAGER_H
+#include <QtCore/QObject>
+#include <kxmlguiwindow.h>
+#include <Q3PtrList>
+#include <QIcon>
 
-#include <kmainwindow.h>
-#include <dcopobject.h>
-#include <qptrlist.h>
+namespace Experimental
+{
+    class KNotificationItem;
+}
 
-class KSystemTray;
 class KWalletIconView;
-class QIconViewItem;
-class DCOPRef;
+class Q3IconViewItem;
+class OrgKdeKWalletInterface;
 
-
-class KWalletManager : public KMainWindow, public DCOPObject {
+class KWalletManager : public KXmlGuiWindow {
 	Q_OBJECT
-	K_DCOP
+
+	    Q_CLASSINFO("D-Bus Interface", "org.kde.kwallet.kwalletmanager")
 
 	public:
-		KWalletManager(QWidget *parent = 0, const char* name = 0, WFlags f = 0);
+		explicit KWalletManager(QWidget *parent = 0, const char* name = 0, Qt::WFlags f = 0);
 		virtual ~KWalletManager();
 
-                QPixmap loadSystemTrayIcon(const QString &icon);
-
 		void kwalletdLaunch();
 
 	public slots:
@@ -50,34 +52,34 @@ class KWalletManager : public KMainWindow, public DCOPObject {
 		void openWallet(const QString& walletName);
 		void openWallet(const QString& walletName, bool newWallet);
 		void openWalletFile(const QString& path);
-		void openWallet(QIconViewItem *item);
-		void contextMenu(QIconViewItem *item, const QPoint& pos);
+		void openWallet(Q3IconViewItem *item);
+		void contextMenu(Q3IconViewItem *item, const QPoint& pos);
 
 	protected:
 		virtual bool queryClose();
 
 	private:
-	k_dcop:
-		ASYNC allWalletsClosed();
-		ASYNC updateWalletDisplay();
-		ASYNC aWalletWasOpened();
+	public Q_SLOTS: //dbus
+		Q_SCRIPTABLE void allWalletsClosed();
+		Q_SCRIPTABLE void updateWalletDisplay();
+		Q_SCRIPTABLE void aWalletWasOpened();
 
 	private slots:
 		void shuttingDown();
 		void possiblyQuit();
-		void editorClosed(KMainWindow* e);
-		void possiblyRescan(const QCString& app);
+		void editorClosed(KXmlGuiWindow* e);
+		void possiblyRescan(const QString& app, const QString&, const QString&);
 		void setupWallet();
 		void openWallet();
 		void deleteWallet();
 		void closeAllWallets();
 
 	private:
-		KSystemTray *_tray;
+		Experimental::KNotificationItem *_tray;
 		bool _shuttingDown;
 		KWalletIconView *_iconView;
-		DCOPRef *_dcopRef;
-		QPtrList<KMainWindow> _windows;
+		OrgKdeKWalletInterface *m_kwalletdModule;
+		Q3PtrList<KXmlGuiWindow> _windows;
 		bool _kwalletdLaunch;
 };
 
