@@ -125,9 +125,34 @@ void KByteArrayModel::removeAllBookmarks()
     d->removeAllBookmarks();
 }
 
-KHECore::BookmarkList KByteArrayModel::bookmarkList() const
+void KByteArrayModel::setBookmark( unsigned int index, const KHECore::Bookmark& bookmark )
 {
-    return d->bookmarkList();
+    d->setBookmark( index, bookmark );
+}
+
+KHECore::BookmarksConstIterator KByteArrayModel::createBookmarksConstIterator() const
+{
+    return d->createBookmarksConstIterator();
+}
+
+const KHECore::Bookmark& KByteArrayModel::bookmarkFor( int offset ) const
+{
+    return d->bookmarkFor( offset );
+}
+
+const KHECore::Bookmark& KByteArrayModel::bookmarkAt( unsigned int index ) const
+{
+    return d->bookmarkAt( index );
+}
+
+bool KByteArrayModel::containsBookmarkFor( int offset ) const
+{
+    return d->containsBookmarkFor( offset );
+}
+
+unsigned int KByteArrayModel::bookmarksCount() const
+{
+    return d->bookmarksCount();
 }
 
 KByteArrayModel::~KByteArrayModel()
